const FileManagerPlugin = require('filemanager-webpack-plugin');
const MiniCssExtractPlugin = require("mini-css-extract-plugin")
const path = require('path')
const RemoveEmptyScriptsPlugin = require("webpack-remove-empty-scripts")

// Structure
const structure = require('./.webpack.structure.js')
let entry = {}
let clean_dist = [] // remove entries from /dist/assets 
let items = [...Object.entries( structure ).concat(Object.values( entry )) ]
for( let [key, item] of items ) {

  if( item.ext !== undefined ) {      
    entry[key] =  path.join( __dirname, item.path + key + '.' + item.ext )

    if( item.clean_js == true ) {
      let js = path.join( __dirname, '/dist/js/' + key + '.min.js' )
      clean_dist.push( js )
    }
    if( item.clean_css == true ) {
      let css = path.join( __dirname, './dist/css/' + key + '.min.css' )
      clean_dist.push( css )
    }  
  }
}
clean_more = [
  __dirname + '/dist/js/*.txt',
]
clean_dist = clean_dist.concat( clean_more )

module.exports = {

  entry,
  
  output: {
    filename: 'js/[name].min.js', //-[chunkhash:8]
    path: path.resolve(__dirname, 'dist/'),
    clean: true,
    publicPath: '/dist/',
  },

  plugins: [

    new FileManagerPlugin({
      events: { 
        onEnd: {
          delete: clean_dist
        },      
      }
    }),
    new RemoveEmptyScriptsPlugin(),
    new MiniCssExtractPlugin({
      linkType: "text/css",
      filename: "css/[name].min.css", //-[chunkhash:8]
    }),
  ],

  module: {
    rules: [
      {
        test: /\.m?js$/,
        exclude: /(node_modules|bower_components)/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: ['@babel/preset-env'],
            plugins: ['@babel/plugin-proposal-object-rest-spread']
          }
        }
      },
      {
        test: /\.(sa|sc|c)ss$/i,
        use: [
          MiniCssExtractPlugin.loader, 
          {
            loader: "css-loader",
            options: {
              sourceMap: true,
            },
          },
          {
            loader: "postcss-loader",
            options: {
              sourceMap: true,
            },
          },
          {
            loader: "sass-loader",
            options: {
              sourceMap: true,
            },
          },
        ],
      }
    ],
  },
};