<?php

/**
 * @file
 * Add custom theme settings to the dsfr base theme.
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\filter\Entity\FilterFormat;
use Drupal\editor\Entity\Editor;

/**
 * Implements hook_form_system_theme_settings_alter().
 */
function dsfr_form_system_theme_settings_alter(&$form, FormStateInterface $form_state, $form_id = NULL) {

  $form['dsfr'] = array(
    '#title' => t('Customize the') . ' ' . t('DSFR Theme'). ' ' . t('based on') . ' ' . '<a href="https://systeme-de-design.gouv.fr/" target="_blank">'. t('French State DESIGN SYSTEM') .'</a>',
    '#type' => 'vertical_tabs',
    '#default_tab' => 'edit-dsfr-general',
    '#weight' => -10,
  );

  // dsfr general settings.
  $form['general'] = [
    '#type' => 'details',
    '#title' => t('General'),
    '#description' => t('Contains recurring elements throughout the theme.'),
    '#group' => 'dsfr',
    '#tree' => TRUE,
  ];

  $form['general']['institution'] = [
    '#type' => 'textfield',
    '#title' => t('Name of official (or parent) institution.'),
    '#description' => t('Mandatory label that will appear <strong>under</strong> the <strong><em>Marianne</em> logo</strong>.')
    .t('<br>By default or empty, the label will be «République &lt;br&gt; Française».')
    .t('<br><strong>Important:</strong> Add the tag &lt;br&gt; for a new line.'),
    '#default_value' => theme_get_setting('general.institution'),
    '#attributes' => ['placeholder' => t('Example') . ': République <br> Française'],
  ];

  // -------------------------------------------------------------------------------------------------------------- //
  // header tab
  $form['header'] = [
    '#type' => 'details',
    '#title' => t('Header'),
    '#group' => 'dsfr',
    '#tree' => TRUE
  ];

  $form['header']['container'] = [
    '#type' => 'checkbox',
    '#prefix' => '<h3> ' . t('Size') . '</h3>',
    '#title' => t('The header') . ' ' . t('will take up the FULL WIDTH of the page.'),
    '#default_value' => theme_get_setting('header.container')
  ];
  $form['header']['logo']['img'] = [
    '#type' => 'checkbox',
    '#prefix' => '<br><hr><h3> ' . t('Logo') . '</h3>',
    '#title' => t('HIDE your personal logo IMAGE') . ' ' . t('(header only)'),
    '#default_value' => theme_get_setting('header.logo.img')
  ];
  $form['header']['logo']['text'] = [
    '#type' => 'checkbox',
    '#title' => t('HIDE your personal logo TEXT -name/service-') . ' ' . t('(header only)'),
    '#default_value' => theme_get_setting('header.logo.text')
  ];
  $form['header']['settings'] = [
    '#type' => 'checkbox',
    '#prefix' => '<br><hr><h3> ' . t('Display settings') . '</h3>',
    '#title' => t('Activate display settings'),
    '#default_value' => theme_get_setting('header.settings')
  ];

  // -------------------------------------------------------------------------------------------------------------- //
  // main navigation tab
  $form['navigation'] = [
    '#type' => 'details',
    '#title' => t('Main menu'),
    '#group' => 'dsfr',
    '#tree' => TRUE
  ];
  $form['navigation']['container'] = [
    '#type' => 'checkbox',
    '#prefix' => '<h3> ' . t('Size') . '</h3>',
    '#title' => t('The navigation') . ' ' . t('will take up the FULL WIDTH of the page.'),
    '#default_value' => theme_get_setting('navigation.container')
  ];

  // -------------------------------------------------------------------------------------------------------------- //
  // important information tab

  $format_text = 'important';

  if( FilterFormat::load( $format_text. '_html' ) === null ) {

    $filter = FilterFormat::create([
      'format' => $format_text . '_html', 
      'name' => ucfirst($format_text) . ' HTML',
      'filters' => [
        'filter_html' => [
          'id' =>  'filter_html',
          'provider' =>  'filter',
          'status' => true,
          'weight' => -10,
          'settings' => [
            'allowed_html' => '<a href hreflang> <em> <strong>',
            'filter_html_help' => true,
            'filter_html_nofollow' => false
          ]
        ]
      ]
    ]);
    $filter->save();
  
    $editor = Editor::create([
      'format'=> $format_text . '_html', 
      'editor'=>'ckeditor5',
      'settings' => [
        'toolbar' =>  [
          'rows' => [[
            [
              'name' => 'Formatting',
              'items' => ['Bold', 'Italic'],
            ],
            [
              'name' => 'Links',
              'items' => ['DrupalLink', 'DrupalUnlink'],
            ],
            [
              'name' => 'Tools',
              'items' => ['Source'],
            ] 
          ]]
        ]
      ]
    ]
    );
    $editor->save();
  }

  // -------------------------------------------------------------------------------------------------------------- //
  // content tab
  $form['hero'] = [
    '#type' => 'details',
    '#title' => t('Hero'),
    '#group' => 'dsfr',
    '#tree' => TRUE
  ];
  $form['hero']['container'] = [
    '#type' => 'checkbox',
    '#prefix' => '<h3> ' . t('Size') . '</h3>',
    '#title' => t('The Hero') . ' ' . t('will take up the FULL WIDTH of the page.'),
    '#default_value' => theme_get_setting('hero.container')
  ];
  
  $form['hero']['margin']['top'] = [
    '#type' => 'select',
    '#prefix' => '<br><hr><h3> ' . t('Margin') . '</h3>',
    '#title' => t('Margin top'),
    '#description' => t('Distance between the header and the hero.'),
    '#default_value' => theme_get_setting('hero.margin.top'),
    '#options' => [
      0 => t('None'), 
      1 => t('Minimal size'), 
      2 => '2 x ' . t('minimal size'),
      3 => '3 x ' . t('minimal size') . ' (' . t('by default') . ')', 
      4 => '4 x ' . t('minimal size'),
      5 => '5 x ' . t('minimal size'), 
      6 => '6 x ' . t('minimal size'),
      7 => '7 x ' . t('minimal size'),
      8 => '8 x ' . t('minimal size'), 
      9 => '9 x ' . t('minimal size')
    ]
  ];
  $form['hero']['margin']['bottom'] = [
    '#type' => 'select',
    '#title' => t('Margin bottom'),
    '#description' => t('Distance between the hero and the main content.'),
    '#default_value' => theme_get_setting('hero.margin.bottom'),
    '#options' => [
      0 => t('None'), 
      1 => t('Minimal size'), 
      2 => '2 x ' . t('minimal size'),
      3 => '3 x ' . t('minimal size') . ' (' . t('by default') . ')', 
      4 => '4 x ' . t('minimal size'),
      5 => '5 x ' . t('minimal size'), 
      6 => '6 x ' . t('minimal size'),
      7 => '7 x ' . t('minimal size'),
      8 => '8 x ' . t('minimal size'), 
      9 => '9 x ' . t('minimal size')
    ]
  ];

  // -------------------------------------------------------------------------------------------------------------- //
  // breadcrumb tab
  $form['breadcrumb'] = [
    '#type' => 'details',
    '#title' => t('Breadcrumb'),
    '#group' => 'dsfr',
    '#tree' => TRUE
  ];
  /*$form['breadcrumb']['container'] = [
    '#type' => 'checkbox',
    '#prefix' => '<h3> ' . t('Size') . '</h3>',
    '#title' => t('The breadcrumb') . ' ' . t('will take up the FULL WIDTH of the page.'),
    '#default_value' => theme_get_setting('breadcrumb.container')
  ];*/
  $form['breadcrumb']['Position'] = [
    '#type' => 'select',
    '#prefix' => '<h3> ' . t('Position') . '</h3>',
    '#description' => t('The breadcrumb can be positioned horizontally to the left, centre and right...'),
    '#default_value' => theme_get_setting('breadcrumb.position'),
    '#options' => [
      0 => t('Left'), 
      1 => t('Center'), 
      2 => t('Right')
    ]
  ];

  // -------------------------------------------------------------------------------------------------------------- //
  // content tab
  $form['content'] = [
    '#type' => 'details',
    '#title' => t('Content'),
    '#group' => 'dsfr',
    '#tree' => TRUE
  ];
  $form['content']['container'] = [
    '#type' => 'checkbox',
    '#prefix' => '<h3> ' . t('Size') . '</h3>',
    '#title' => t('The main content') . ' ' . t('will take up the FULL WIDTH of the page.'),
    '#default_value' => theme_get_setting('content.container')
  ];
  
  $form['content']['margin']['top'] = [
    '#type' => 'select',
    '#prefix' => '<br><hr><h3> ' . t('Margin') . '</h3>',
    '#title' => t('Margin top'),
    '#description' => t('Distance between the header or the hero and the main content.'),
    '#default_value' => theme_get_setting('content.margin.top'),
    '#options' => [
      0 => t('None'), 
      1 => t('Minimal size'), 
      2 => '2 x ' . t('minimal size'),
      3 => '3 x ' . t('minimal size') . ' (' . t('by default') . ')', 
      4 => '4 x ' . t('minimal size'),
      5 => '5 x ' . t('minimal size'), 
      6 => '6 x ' . t('minimal size'),
      7 => '7 x ' . t('minimal size'),
      8 => '8 x ' . t('minimal size'), 
      9 => '9 x ' . t('minimal size')
    ]
  ];
  $form['content']['margin']['bottom'] = [
    '#type' => 'select',
    '#title' => t('Margin bottom'),
    '#description' => t('Distance between the main content and the footer.'),
    '#default_value' => theme_get_setting('content.margin.bottom'),
    '#options' => [
      0 => t('None'), 
      1 => t('Minimal size'), 
      2 => '2 x ' . t('minimal size'),
      3 => '3 x ' . t('minimal size'), 
      4 => '4 x ' . t('minimal size'),
      5 => '5 x ' . t('minimal size'), 
      6 => '6 x ' . t('minimal size') . ' (' . t('by default') . ')',
      7 => '7 x ' . t('minimal size'),
      8 => '8 x ' . t('minimal size'), 
      9 => '9 x ' . t('minimal size')
    ]
  ];

  // -------------------------------------------------------------------------------------------------------------- //
  // FOOTER TOP
  $form['footer_top'] = [
    '#type' => 'details',
    '#title' => t('Footer Top'),
    '#group' => 'dsfr',
    '#tree' => TRUE
  ];
  $form['footer_top']['container'] = [
    '#type' => 'checkbox',
    '#prefix' => '<h3> ' . t('Size') . '</h3>',
    '#title' => t('The footer top'). ' ' . t('will take up the FULL WIDTH of the page.'),
    '#default_value' => theme_get_setting('footer_top.container'),
  ];

  // -------------------------------------------------------------------------------------------------------------- //
  // FOOTER
  $form['footer'] = [
    '#type' => 'details',
    '#title' => t('Footer'),
    '#group' => 'dsfr',
    '#tree' => TRUE
  ];
  $form['footer']['container'] = [
    '#type' => 'checkbox',
    '#prefix' => '<h3> ' . t('Size') . '</h3>',
    '#title' => t('The footer') . ' ' . t('will take up the FULL WIDTH of the page.'),
    '#default_value' => theme_get_setting('footer.container'),
  ];
  $form['footer']['logo']['img'] = [
    '#type' => 'checkbox',
    '#prefix' => '<br><hr><h3> ' . t('Logo') . '</h3>',
    '#title' => t('HIDE your personal logo IMAGE') . ' ' . t('(footer only)'),
    '#default_value' => theme_get_setting('footer.logo.img'),
  ];

  $form['footer']['last_line'] = [
    '#type' => 'checkbox',
    '#prefix' => '<br><hr><h3> ' . t('Last line') . '</h3>',
    '#title' => t('SHOW the line') . ' <strong>«' . t('Unless otherwise stated, all texts on this site are under')  . ' licence etalab-2.0 »</strong>',
    '#default_value' => theme_get_setting('footer.last_line'),
  ];

}